// This file is part of Notepad++ project
// Copyright (C)2021 Don HO <don.h@free.fr>

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.

#pragma once

#define	IDD_RUN_DLG      1900
#define	IDC_BUTTON_FILE_BROWSER	(IDD_RUN_DLG + 1)
#define	IDC_COMBO_RUN_PATH		(IDD_RUN_DLG + 2)
#define	IDC_MAINTEXT_STATIC     (IDD_RUN_DLG + 3)
#define	IDC_BUTTON_SAVE         (IDD_RUN_DLG + 4)
#define	IDC_BUTTON_VARIABLES    (IDD_RUN_DLG + 5)
#define	IDR_RUN_DLG_MENU_VARIABLES 1950
#define IDM_RUN_DLG_VARMENU_START (IDD_RUN_DLG + 60)
#define IDM_RUN_DLG_VARMENU_END (IDM_RUN_DLG_VARMENU_START + 10)
